import { BufWrapper } from '@minecraft-js/bufwrapper';
declare type MapResolvable = {
    [key: string]: string;
};
/**
 * Write a map to the buffer
 *
 * An object with an UUID as key and a
 * string as value is considered a map.
 * @param value Value to write to the buffer
 * @example
 * ```javascript
 * const buf = new BufWrapper(null, {
 *   plugins: { lunar: BufWrapperLunarPlugin }
 * });
 *
 * const map = {
 *   '827f8c48-cdb2-4105-af39-df5a64f93490': 'Hello World!'
 * };
 *
 * buf.plugins.lunar.writeMap(map);
 * ```
 */
export declare function writeMap(this: BufWrapper, value: MapResolvable): void;
/**
 * Read a map from the buffer
 *
 * An object with an UUID as key and a
 * string as value is considered a map.
 * @returns The read map
 * @example
 * ```javascript
 * // `data` is the source buffer
 * const buf = new BufWrapper(data, {
 *   plugins: { lunar: BufWrapperLunarPlugin }
 * });
 *
 * buf.plugins.lunar.readMap(map); // { ... }
 * ```
 */
export declare function readMap(this: BufWrapper): MapResolvable;
/**
 * Write a blobl to the buffer
 *
 * An array of bytes is considered a blob.
 * @param value Value to write to the buffer
 * @example
 * ```javascript
 * const buf = new BufWrapper(null, {
 *   plugins: { lunar: BufWrapperLunarPlugin }
 * });
 *
 * buf.plugins.lunar.writeBlob([4, 150, 254, 6]);
 * ```
 */
export declare function writeBlob(this: BufWrapper, value: number[]): void;
/**
 * Read a blob from the buffer
 *
 * An array of bytes is considered a blob.
 * @returns The read blob
 * @example
 * ```javascript
 * // `data` is the source buffer
 * const buf = new BufWrapper(data, {
 *   plugins: { lunar: BufWrapperLunarPlugin }
 * });
 *
 * buf.plugins.lunar.readBlob(map); // [ ... ]
 * ```
 */
export declare function readBlob(this: BufWrapper): number[];
export {};
